@@ -265,7 +265,7 @@ NewGameDlg::NewGameDlg( QWidget *parent, Map *pmap, QList<Player *> *players,
     m_w->playerList->setModel(model);
     m_w->playerList->setItemDelegate(new playersListDelegate(this));
     m_w->playerList->header()->setResizeMode(QHeaderView::Stretch);
-
+    
     connect(m_w->neutralPlanetsSB, SIGNAL(valueChanged(int)), this, SLOT(slotNewMap()));
     connect(m_w->widthSB, SIGNAL(valueChanged(int)), this, SLOT(slotNewMap()));
     connect(m_w->heightSB, SIGNAL(valueChanged(int)), this, SLOT(slotNewMap()));
@@ -292,20 +292,26 @@ NewGameDlg::init()
        nrOfPlayers = MAX_PLAYERS;
 
     int nrOfPlanets = config.readEntry("NrOfPlanets", 3);
-       
+    int sizeWid = config.readEntry("SizeWidth", 10);
+    int sizeHeight = config.readEntry("SizeHeight", 10);
+
     m_w->neutralPlanetsSB->setValue(nrOfPlanets);
+    m_w->widthSB->setValue(sizeWid);
+    m_w->heightSB->setValue(sizeHeight);
     
     // Restore player names
     playersListModel *model = static_cast<playersListModel*>(m_w->playerList->model());
     for(int i = 0; i < nrOfPlayers; ++i)
     {
-       QString key = QString("Player_%1").arg(i);
+       QString keyName = QString("Player_%1").arg(i);
+       QString keyType = QString("PlayerType_%1").arg(i);
        
-       QString playerName = config.readEntry(key,QString());
+       QString playerName = config.readEntry(keyName,QString());
+       QString playerType = config.readEntry(keyType,QString());
        
        model->addPlayer();
-       
        if (!playerName.isEmpty()) model->setData(model->index(i, 0), playerName, Qt::EditRole);
+       model->setData(model->index(i, 1), playerType, Qt::EditRole);
     }
 }
 
@@ -348,22 +354,20 @@ NewGameDlg::save()
     KConfigGroup config = KGlobal::config()->group("Game");
     
     config.writeEntry("NrOfPlanets", m_w->neutralPlanetsSB->value());
+    config.writeEntry("SizeWidth", m_w->widthSB->value());
+    config.writeEntry("SizeHeight", m_w->heightSB->value());
 
     playersListModel *model = static_cast<playersListModel*>(m_w->playerList->model());
+    config.writeEntry("NrOfPlayers", model->rowCount());
     for (int i = 0; i < model->rowCount(); ++i)
     {
-        QString  key        = QString("Player_%1").arg(i);
+        QString  keyName        = QString("Player_%1").arg(i);
         QString  playerName = model->data(model->index(i, 0), Qt::DisplayRole).toString();
+        QString  keyType = QString("PlayerType_%1").arg(i);
+        QString  playerType = model->data(model->index(i, 1), Qt::DisplayRole).toString();
 
-        // TODO this is a bit ugly, maybe a isAI in model will be better
-        bool ai = model->data(model->index(i, 1), Qt::DisplayRole).toString() != i18nc("A human player", "Human");
-        if (ai) {
-           if (config.hasKey(key))
-              config.deleteEntry(key);
-        }
-        else {
-           config.writeEntry(key, playerName);
-        }
+        config.writeEntry(keyName, playerName);
+        config.writeEntry(keyType, playerType);
     }
     config.sync();
 }
