@@ -12,10 +12,12 @@
  * other special, indirect and consequential damages.
 */
 #include "deck.h"
-#include <kdebug.h>
 #include "dealer.h"
-#include <time.h>
-#include <assert.h>
+
+#include <ctime>
+#include <cassert>
+
+#include <kdebug.h>
 
 const unsigned int NumberOfCards = 52;
 
@@ -54,6 +56,12 @@ Deck::~Deck()
     delete [] _deck;
 }
 
+void Deck::destroy_deck()
+{
+    Q_ASSERT( my_deck );
+    delete my_deck;
+    my_deck = 0;
+}
 
 // ----------------------------------------------------------------
 
