@@ -1,17 +1,19 @@
 /* Common routines & arrays. */
 
 #include "patsolve.h"
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
-#include <math.h>
-#include <kdebug.h>
-#include <stdarg.h>
-#include <sys/types.h>
 #include "../pile.h"
 #include "memory.h"
 
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cctype>
+#include <cmath>
+#include <cstdarg>
+#include <sys/types.h>
+
+#include <kdebug.h>
+
 long all_moves = 0;
 
 /* This is a 32 bit FNV hash.  For more information, see
@@ -877,6 +879,17 @@ Solver::Solver()
 Solver::~Solver()
 {
     delete mm;
+
+    for ( int i = 0; i < m_number_piles; i++ )
+    {
+        delete [] W[i];
+    }
+
+    delete [] W;
+    delete [] Wp;
+    delete [] Wlen;
+    delete [] Whash;
+    delete [] Wpilenum;
 }
 
 void Solver::init()
