@@ -19,12 +19,20 @@
 */
 
 #include "pwidget.h"
+#include "pile.h"
+#include "version.h"
+#include "dealer.h"
+#include "view.h"
+#include "cardmaps.h"
+#include "gamestatsimpl.h"
+#include "demo.h"
+#include <carddeckinfo.h>
 
-#include <stdio.h>
+#include <cstdio>
 
 #include <QRegExp>
 #include <QTimer>
-#include <qimage.h>
+#include <QImage>
 //Added by qt3to4:
 #include <QPixmap>
 #include <QTextStream>
@@ -42,7 +50,6 @@
 #include <kstandardaction.h>
 #include <kstandardgameaction.h>
 #include <kdebug.h>
-#include <carddeckinfo.h>
 #include <kcarddialog.h>
 #include <krandom.h>
 #include <kinputdialog.h>
@@ -59,13 +66,6 @@
 #include <kicon.h>
 #include <kconfiggroup.h>
 
-#include "pile.h"
-#include "version.h"
-#include "dealer.h"
-#include "view.h"
-#include "cardmaps.h"
-#include "gamestatsimpl.h"
-
 
 static pWidget *current_pwidget = 0;
 
@@ -76,10 +76,12 @@ pWidget::pWidget()
     current_pwidget = this;
     // KCrash::setEmergencySaveFunction(::saveGame);
 
-
+    KAction *a;
     // Game
-    KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
-    KStandardGameAction::restart(this, SLOT(restart()), actionCollection());
+    a = KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
+    a->setEnabled( false );
+    a = KStandardGameAction::restart(this, SLOT(restart()), actionCollection());
+    a->setEnabled( false );
     KStandardGameAction::load(this, SLOT(openGame()), actionCollection());
     recent = KStandardGameAction::loadRecent(this, SLOT(openGame(const KUrl&)), actionCollection());
     recent->loadEntries( KGlobal::config()->group( QString() ));
@@ -90,9 +92,14 @@ pWidget::pWidget()
     undo = KStandardGameAction::undo(this, SLOT(undoMove()), actionCollection());
     undo->setEnabled(false);
 
-    QAction *a = actionCollection()->addAction("choose_game");
+    // Move
+    redo = KStandardGameAction::redo(this, SLOT(redoMove()), actionCollection());
+    redo->setEnabled(false);
+
+    a = actionCollection()->addAction("choose_game");
     a->setText(i18n("&Choose Game..."));
     connect( a, SIGNAL( triggered( bool ) ), SLOT( chooseGame() ) );
+    a->setEnabled( false );
 
     actionCollection()->addAction(KStandardAction::Help, "help_game",
                                   this, SLOT(helpGame()));
@@ -112,26 +119,28 @@ pWidget::pWidget()
     for (it = DealerInfoList::self()->games().begin();
          it != DealerInfoList::self()->games().end(); ++it)
     {
-        m_dealer_map[(*it )->gameindex] = list.indexOf( i18n((*it)->name) );
+        for ( QList<int>::const_iterator it2 = (*it )->ids.constBegin(); it2 != (*it )->ids.constEnd(); ++it2)
+            m_dealer_map[*it2] = list.indexOf( i18n((*it)->name) );
     }
 
     games->setItems(list);
 
-    KGlobal::dirs()->addResourceType("wallpaper", "data", "kpat/backgrounds/");
-
-    dill = new PatienceView( this );
-    connect(dill, SIGNAL(saveGame()), SLOT(saveGame()));
-    setCentralWidget(dill);
-
     a = actionCollection()->addAction("random_set");
     a->setText(i18n("Random Cards"));
     connect( a, SIGNAL( triggered( bool ) ), SLOT( slotPickRandom() ) );
     a->setShortcuts( KShortcut( Qt::Key_F9 ) );
+    a->setEnabled( false );
+
+    a = actionCollection()->addAction("snapshot");
+    connect( a, SIGNAL( triggered( bool ) ), SLOT( slotSnapshot() ) );
+    if (getenv("KDE_DEBUG")) // developer shortcut
+       a->setShortcuts( KShortcut( Qt::Key_F8 ) );
 
     a = actionCollection()->addAction("select_deck");
     a->setText(i18n("Select Deck..."));
     connect( a, SIGNAL( triggered( bool ) ), SLOT( slotSelectDeck() ) );
     a->setShortcuts( KShortcut( Qt::Key_F10 ) );
+    a->setEnabled( false );
 
     m_cards = new cardMap();
 
@@ -142,14 +151,23 @@ pWidget::pWidget()
     dropaction = new KToggleAction(i18n("&Enable Autodrop"), this);
     actionCollection()->addAction("enable_autodrop", dropaction);
     connect( dropaction, SIGNAL( triggered( bool ) ), SLOT(enableAutoDrop()) );
+    a->setEnabled( false );
+
+    solveraction = new KToggleAction(i18n("E&nable Solver"), this);
+    actionCollection()->addAction("enable_solver", solveraction);
+    connect( solveraction, SIGNAL( triggered( bool ) ), SLOT( enableSolver() ) );
+    a->setEnabled( false );
 
     KConfigGroup cg(KGlobal::config(), settings_group );
 
     bool autodrop = cg.readEntry("Autodrop", true);
     dropaction->setChecked(autodrop);
 
-    int game = cg.readEntry("DefaultGame", 0);
-    games->setCurrentItem( m_dealer_map[game] );
+    bool solver = cg.readEntry("Solver", true);
+    solveraction->setChecked(solver);
+
+    //int game = cg.readEntry("DefaultGame", 0);
+    //games->setCurrentItem( m_dealer_map[game] );
 
     statusBar()->insertPermanentItem( "", 1, 0 );
     setupGUI(qApp->desktop()->availableGeometry().size()*0.7); // QString()/*, false*/);
@@ -157,6 +175,14 @@ pWidget::pWidget()
 
     // QTimer::singleShot( 0, this, SLOT( newGameType() ) );
     setAutoSaveSettings();
+
+    m_dealer_it = m_dealer_map.constEnd();
+
+    dill = 0;
+
+    m_bubbles = new DemoBubbles( this );
+    setCentralWidget( m_bubbles );
+    connect( m_bubbles, SIGNAL( gameSelected( int ) ), SLOT( slotGameSelected( int ) ) );
 }
 
 pWidget::~pWidget()
@@ -171,6 +197,11 @@ void pWidget::undoMove() {
         dill->dscene()->undo();
 }
 
+void pWidget::redoMove() {
+    if( dill && dill->dscene() )
+        dill->dscene()->redo();
+}
+
 void pWidget::helpGame()
 {
     if (!dill)
@@ -183,12 +214,27 @@ void pWidget::undoPossible(bool poss)
     undo->setEnabled(poss);
 }
 
+void pWidget::redoPossible(bool poss)
+{
+    redo->setEnabled(poss);
+}
+
 void pWidget::enableAutoDrop()
 {
     bool drop = dropaction->isChecked();
     KConfigGroup cg(KGlobal::config(), settings_group );
     cg.writeEntry( "Autodrop", drop);
-    dill->setAutoDropEnabled(drop);
+    if ( dill )
+        dill->setAutoDropEnabled(drop);
+}
+
+void pWidget::enableSolver()
+{
+    bool solver = solveraction->isChecked();
+    KConfigGroup cg(KGlobal::config(), settings_group );
+    cg.writeEntry( "Solver", solver );
+    if ( dill )
+        dill->setSolverEnabled(solver);
 }
 
 void pWidget::newGame()
@@ -275,6 +321,12 @@ void pWidget::setGameCaption()
     setCaption( newname + " - " + gamenum );
 }
 
+void pWidget::slotGameSelected( int i )
+{
+    games->setCurrentItem( m_dealer_map[i] );
+    slotNewGameType();
+}
+
 void pWidget::slotNewGameType()
 {
     newGameType();
@@ -289,19 +341,41 @@ void pWidget::newGameType()
     int item = games->currentItem();
     int id = -1;
 
-    kDebug(11111) << "newGameType" << id;
-    for (QList<DealerInfo*>::ConstIterator it = DealerInfoList::self()->games().begin();
-	it != DealerInfoList::self()->games().end(); ++it) {
+    if ( !dill )
+    {
+        m_bubbles->deleteLater();
+        m_bubbles = 0;
+        dill = new PatienceView( this );
+        connect(dill, SIGNAL(saveGame()), SLOT(saveGame()));
+        setCentralWidget(dill);
+    }
 
-        if ( m_dealer_map[(*it)->gameindex] == item) {
-            dill->setScene( (*it)->createGame() );
-            QString name = (*it)->name;
-            name = name.replace(QRegExp("[&']"), "");
-            name = name.replace(QRegExp("[ ]"), "_").toLower();
-            dill->setAnchorName("game_" + name);
-            id = (*it)->gameindex;
-            dill->dscene()->setGameId( id );
-            break;
+    actionCollection()->action( "random_set" )->setEnabled( true );
+    actionCollection()->action( "choose_game" )->setEnabled( true );
+    actionCollection()->action( "enable_autodrop" )->setEnabled( true );
+    actionCollection()->action( "enable_solver" )->setEnabled( true );
+    actionCollection()->action( "game_new" )->setEnabled( true );
+    actionCollection()->action( "game_restart" )->setEnabled( true );
+    actionCollection()->action( "select_deck" )->setEnabled( true );
+
+    kDebug(11111) << "newGameType" << item;
+    for (QList<DealerInfo*>::ConstIterator it = DealerInfoList::self()->games().begin();
+	it != DealerInfoList::self()->games().end(); ++it)
+    {
+        for (QList<int>::const_iterator it2 = (*it )->ids.constBegin();
+	     it2 != (*it )->ids.constEnd(); ++it2)
+        {
+            if ( m_dealer_map[*it2] == item)
+            {
+                dill->setScene( (*it)->createGame() );
+                QString name = (*it)->name;
+                name = name.replace(QRegExp("[&']"), "");
+                name = name.replace(QRegExp("[ ]"), "_").toLower();
+                dill->setAnchorName("game_" + name);
+                id = *it2;
+                dill->dscene()->setGameId( id );
+                break;
+            }
         }
     }
 
@@ -311,9 +385,12 @@ void pWidget::newGameType()
         dill->setScene( DealerInfoList::self()->games().first()->createGame() );
     }
 
+    enableAutoDrop();
+    enableSolver();
 
     kDebug(11111) << "dill" << dill << " " << dill->dscene();
     connect(dill->dscene(), SIGNAL(undoPossible(bool)), SLOT(undoPossible(bool)));
+    connect(dill->dscene(), SIGNAL(redoPossible(bool)), SLOT(redoPossible(bool)));
     connect(dill->dscene(), SIGNAL(gameLost()), SLOT(gameLost()));
     connect(dill->dscene(), SIGNAL(gameInfo(const QString&)),
             SLOT(slotGameInfo(const QString &)));
@@ -340,7 +417,8 @@ void pWidget::newGameType()
 void pWidget::showEvent(QShowEvent *e)
 {
     kDebug(11111) << "showEvent ";
-    dill->setWasShown( true );
+    if ( dill )
+        dill->setWasShown( true );
     KXmlGuiWindow::showEvent(e);
 }
 
@@ -392,11 +470,15 @@ void pWidget::openGame(const KUrl &url)
 
         games->setCurrentItem(m_dealer_map[id]);
         newGameType();
+
         if (!dill->dscene()) {
            KMessageBox::error(this, i18n("The saved game is of unknown type!"));
            games->setCurrentItem(0);
            newGameType();
         }
+        // for old spider and klondike
+        dill->dscene()->mapOldId( id );
+
         show();
         dill->dscene()->openGame(doc);
         setGameCaption();
@@ -414,15 +496,10 @@ void pWidget::openGame()
 
 void pWidget::saveGame()
 {
+    if (!dill)
+       return;
     KUrl url = KFileDialog::getSaveUrl();
-    KTemporaryFile file;
-    file.open();
-    QDomDocument doc("kpat");
-    dill->dscene()->saveGame(doc);
-    QTextStream stream (&file);
-    stream << doc.toString();
-    stream.flush();
-    KIO::NetAccess::upload(file.fileName(), url, this);
+    KIO::NetAccess::upload(dill->dscene()->save_it(), url, this);
     recent->addUrl(url);
     recent->saveEntries( KGlobal::config()->group( QString() ) );
 }
@@ -455,5 +532,35 @@ void pWidget::slotGameSolverUnknown()
     statusBar()->showMessage( i18n( "Timeout while playing - unknown if it can be won" ) );
 }
 
+void pWidget::slotSnapshot()
+{
+    if ( m_dealer_it == m_dealer_map.constEnd() )
+    {
+        // first call
+        m_dealer_it = m_dealer_map.constBegin();
+    }
+
+    games->setCurrentItem(m_dealer_it.value());
+    newGameType();
+    restart();
+    m_dealer_it++;
+    QTimer::singleShot( 200, this, SLOT( slotSnapshot2() ) );
+}
+
+void pWidget::slotSnapshot2()
+{
+    if ( dill->dscene()->waiting() ) {
+            QTimer::singleShot( 100, this, SLOT( slotSnapshot2() ) );
+            return;
+    }
+    QImage img = QImage( dill->size(), QImage::Format_ARGB32 );
+    img.fill( qRgba( 0, 0, 255, 0 ) );
+    dill->dscene()->createDump( &img );
+    img = img.scaled( 320, 320, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+    img.save( QString( "out_%1.png" ).arg( dill->dscene()->gameId() ) );
+    if ( m_dealer_it != m_dealer_map.constEnd() )
+        QTimer::singleShot( 200, this, SLOT( slotSnapshot() ) );
+}
+
 #include "pwidget.moc"
 
