@@ -65,6 +65,7 @@ AIColsonPlayer::AIColsonPlayer(
 
 AIColsonPlayer::~AIColsonPlayer() 
 {
+  delete m_placeData;
 }
 
 //////////////////////////////////////////////////////////
@@ -232,7 +233,7 @@ bool AIColsonPlayer::moveArmiesAction()
 int AIColsonPlayer::getTotalArmiesOfPlayer(const Player* player)
 {
   int nb = 0;
-  for (unsigned int i=0; i<m_world->getCountries().size(); i++)
+  for (int i=0; i<m_world->getCountries().size(); i++)
   {
     if (m_world->getCountries().at(i)->owner() == player)
     {
@@ -247,7 +248,7 @@ bool AIColsonPlayer::isContinentOfMission(const Player* player, const Continent*
 {
   if (player->goal().type() != Goal::Continents)
       return false;
-  return (player->goal().continents().find(continent->id()) != player->goal().continents().end());
+  return (player->goal().continents().contains(continent->name()));
 }
 
 bool AIColsonPlayer::isEnemyPlayer(const Player* player)
@@ -330,8 +331,8 @@ const Continent* AIColsonPlayer::computeChoiceOfContinent(void)
   std::map< const KPlayer*, std::map <const Continent*, bool > > posContinent;
   std::map<const KPlayer*, const Continent*> m_piContinent;
 
-  std::vector<Continent*>::iterator continentsIt = (m_world->getContinents().begin());
-  std::vector<Continent*>::iterator continentsIt_end = (m_world->getContinents().end());
+  QList<Continent*>::iterator continentsIt = (m_world->getContinents().begin());
+  QList<Continent*>::iterator continentsIt_end = (m_world->getContinents().end());
 
   PlayersArray::iterator it = m_game->playerList()->begin();
   PlayersArray::iterator it_end = m_game->playerList()->end();
@@ -352,10 +353,10 @@ const Continent* AIColsonPlayer::computeChoiceOfContinent(void)
     }
   }
 
-  for (unsigned int i=0; i<m_world->getCountries().size(); i++)
+  for (int i=0; i<m_world->getCountries().size(); i++)
   {
-/*  std::vector<Country*>::iterator countriesIt(m_world->getCountries().begin());
-  std::vector<Country*>::iterator countriesIt_end(m_world->getCountries().end());
+/*  QList<Country*>::iterator countriesIt(m_world->getCountries().begin());
+  QList<Country*>::iterator countriesIt_end(m_world->getCountries().end());
   for (; countriesIt != countriesIt_end; countriesIt++)
   {*/
     Country* country = m_world->getCountries().at(i);
@@ -407,8 +408,8 @@ const Continent* AIColsonPlayer::computeChoiceOfContinent(void)
         }
         else if (piCount[*it][continent] > max)
         {
-          std::vector<Continent*>::iterator jit(m_world->getContinents().begin());
-          std::vector<Continent*>::iterator jit_end(m_world->getContinents().end());
+          QList<Continent*>::iterator jit(m_world->getContinents().begin());
+          QList<Continent*>::iterator jit_end(m_world->getContinents().end());
           for (; jit!=jit_end; jit++)
           {
             Continent* j = *jit;
@@ -448,8 +449,8 @@ const Continent* AIColsonPlayer::computeChoiceOfContinent(void)
 
   /* Search a continent with no conflict */
   const Continent* continent = 0;
-  std::vector<Continent*>::iterator contIt(m_world->getContinents().begin());
-  std::vector<Continent*>::iterator contIt_end(m_world->getContinents().end());
+  QList<Continent*>::iterator contIt(m_world->getContinents().begin());
+  QList<Continent*>::iterator contIt_end(m_world->getContinents().end());
   for (;(contIt!=contIt_end) && (continent==0);contIt++)
   {
     const Continent* cont = *contIt;
@@ -477,8 +478,8 @@ const Continent* AIColsonPlayer::computeChoiceOfContinent(void)
 
   if (isFriendPlayer(this) && (continent!=0))
   {
-    std::vector<Continent*>::iterator contIt(m_world->getContinents().begin());
-    std::vector<Continent*>::iterator contIt_end(m_world->getContinents().end());
+    QList<Continent*>::iterator contIt(m_world->getContinents().begin());
+    QList<Continent*>::iterator contIt_end(m_world->getContinents().end());
 #ifdef __GNUC__
 #warning continent can not be 0 in this code path - everything in this for loop is dead code
 #endif
@@ -530,8 +531,8 @@ const Continent* AIColsonPlayer::computeChoiceOfContinent(void)
 
   if (continent!=0)
   {
-    std::vector<Continent*>::iterator contIt(m_world->getContinents().begin());
-    std::vector<Continent*>::iterator contIt_end(m_world->getContinents().end());
+    QList<Continent*>::iterator contIt(m_world->getContinents().begin());
+    QList<Continent*>::iterator contIt_end(m_world->getContinents().end());
     for (;contIt!=contIt_end;contIt++)
     {
       const Continent* cont = *contIt;
@@ -583,8 +584,8 @@ const Continent* AIColsonPlayer::computeChoiceOfContinent(void)
 
   if (continent!=0)
   {
-    std::vector<Continent*>::iterator contIt(m_world->getContinents().begin());
-    std::vector<Continent*>::iterator contIt_end(m_world->getContinents().end());
+    QList<Continent*>::iterator contIt(m_world->getContinents().begin());
+    QList<Continent*>::iterator contIt_end(m_world->getContinents().end());
     for (;contIt!=contIt_end;contIt++)
     {
       const Continent* cont = *contIt;
@@ -635,8 +636,8 @@ const Continent* AIColsonPlayer::computeChoiceOfContinent(void)
 
   if (continent!=0)
   {
-    std::vector<Continent*>::iterator contIt(m_world->getContinents().begin());
-    std::vector<Continent*>::iterator contIt_end(m_world->getContinents().end());
+    QList<Continent*>::iterator contIt(m_world->getContinents().begin());
+    QList<Continent*>::iterator contIt_end(m_world->getContinents().end());
     for (;contIt!=contIt_end;contIt++)
     {
       const Continent* cont = *contIt;
@@ -673,8 +674,8 @@ const Continent* AIColsonPlayer::computeChoiceOfContinent(void)
 
   if (continent!=0)
   {
-    std::vector<Continent*>::iterator contIt(m_world->getContinents().begin());
-    std::vector<Continent*>::iterator contIt_end(m_world->getContinents().end());
+    QList<Continent*>::iterator contIt(m_world->getContinents().begin());
+    QList<Continent*>::iterator contIt_end(m_world->getContinents().end());
     for (;contIt!=contIt_end;contIt++)
     {
       const Continent* cont = *contIt;
@@ -740,8 +741,8 @@ const Continent* AIColsonPlayer::getContinentToConquier(int *attack)
   std::map<const Continent*, int> piAttac;
 
   /* Init. */
-  std::vector<Continent*>::iterator contIt(m_world->getContinents().begin());
-  std::vector<Continent*>::iterator contIt_end(m_world->getContinents().end());
+  QList<Continent*>::iterator contIt(m_world->getContinents().begin());
+  QList<Continent*>::iterator contIt_end(m_world->getContinents().end());
   for (;contIt!=contIt_end;contIt++)
   {
     const Continent* cont = *contIt;
@@ -751,8 +752,8 @@ const Continent* AIColsonPlayer::getContinentToConquier(int *attack)
   }
 
   /* Count up how many countries the player has in each of the continents */
-  std::vector<Country*>::iterator countriesIt(m_world->getCountries().begin());
-  std::vector<Country*>::iterator countriesIt_end(m_world->getCountries().end());
+  QList<Country*>::iterator countriesIt(m_world->getCountries().begin());
+  QList<Country*>::iterator countriesIt_end(m_world->getCountries().end());
   for (; countriesIt != countriesIt_end; countriesIt++)
   {
     Country* country = *countriesIt;
@@ -820,9 +821,9 @@ int AIColsonPlayer::NbEnemyAdjacent(Country* iCountry)
   }
   Player* iEnemy = 0;
   Country* destCountry;
-  std::vector< Country* >::const_iterator it, it_end;
-  it = iCountry->neighbours().begin();
-  it_end = iCountry->neighbours().end();
+  QList<Country*>::const_iterator it, it_end;
+  it = iCountry->neighbours().constBegin();
+  it_end = iCountry->neighbours().constEnd();
   for (;it != it_end; it++)
     {
       destCountry = *it;
@@ -859,9 +860,9 @@ int AIColsonPlayer::NbToAverageEnemyAdjacent(Country* iCountry)
   int nbe = 0;
   int nb = 0;
   int i = 0;
-  std::vector< Country* >::const_iterator neighbourIt, neighbourIt_end;
-  neighbourIt = iCountry->neighbours().begin();
-  neighbourIt_end = iCountry->neighbours().end();
+  QList<Country*>::const_iterator neighbourIt, neighbourIt_end;
+  neighbourIt = iCountry->neighbours().constBegin();
+  neighbourIt_end = iCountry->neighbours().constEnd();
   for (;neighbourIt != neighbourIt_end; neighbourIt++)
   {
     Country* destCountry = *neighbourIt;
@@ -885,9 +886,9 @@ int AIColsonPlayer::NbToAverageEnemyAdjacent(Country* iCountry)
 int AIColsonPlayer::NbToEqualEnemyAdjacent(Country* iCountry)
 {
   int nbe = 0;
-  std::vector< Country* >::const_iterator neighbourIt, neighbourIt_end;
-  neighbourIt = iCountry->neighbours().begin();
-  neighbourIt_end = iCountry->neighbours().end();
+  QList<Country*>::const_iterator neighbourIt, neighbourIt_end;
+  neighbourIt = iCountry->neighbours().constBegin();
+  neighbourIt_end = iCountry->neighbours().constEnd();
   for (;neighbourIt != neighbourIt_end; neighbourIt++)
   {
     Country* destCountry = *neighbourIt;
@@ -910,11 +911,10 @@ bool AIColsonPlayer::ComputerAttack(int destCountry, bool die, int dif)
 {
   kDebug() << destCountry;
 
-  if (  Attack_SrcCountry!=-1
-      && RISK_GetOwnerOfCountry(Attack_SrcCountry) == this
-      && Attack_DestCountry!=-1
-      && (RISK_GetOwnerOfCountry(Attack_DestCountry) != this)
-          && (RISK_GetNumArmiesOfCountry(Attack_SrcCountry) > 1)
+  if (Attack_SrcCountry!=-1 && Attack_DestCountry!=-1
+    && (RISK_GetOwnerOfCountry(Attack_SrcCountry) == this)
+    && (RISK_GetOwnerOfCountry(Attack_DestCountry) != this)
+    && (RISK_GetNumArmiesOfCountry(Attack_SrcCountry) > 1)
           && (die || (   RISK_GetNumArmiesOfCountry(Attack_SrcCountry)
                        > RISK_GetNumArmiesOfCountry(Attack_DestCountry))))
   {
@@ -1371,11 +1371,10 @@ bool AIColsonPlayer::AttackEnemy()
   int nbCountriesWithAdjacentEnemies;
   const Continent* continent = GetContinentToFortify(&nbCountriesWithAdjacentEnemies);
 
-  if (Attack_SrcCountry!=-1
-      && (RISK_GetOwnerOfCountry(Attack_SrcCountry)==this)
-      && Attack_DestCountry != -1
-      && (RISK_GetOwnerOfCountry(Attack_DestCountry)!=this)
-      && ComputerAttack (Attack_DestCountry, true,
+  if (Attack_SrcCountry!=-1 && Attack_DestCountry != -1
+    && (RISK_GetOwnerOfCountry(Attack_SrcCountry)==this)
+    && (RISK_GetOwnerOfCountry(Attack_DestCountry)!=this)
+    && ComputerAttack (Attack_DestCountry, true,
                             (RISK_GetNumArmiesOfCountry(Attack_DestCountry) < 5)?1:
                                 ((nbCountriesWithAdjacentEnemies > 4)?RISK_GetNumArmiesOfCountry(Attack_DestCountry):3)))
   {
@@ -1751,10 +1750,11 @@ bool AIColsonPlayer::Move()
           && !GAME_IsEnemyAdjacent(i))
     {
       max = RISK_GetNumArmiesOfCountry(i);
+      kDebug() << "country " << i << ", num armies:" << max;
       iCountry = i;
     }
   }
-  kDebug() << "1p iCountry=" << iCountry;
+  kDebug() << "1p iCountry=" << iCountry << "; max=" << max;
   if (iCountry>=0)
   {
     int destCountry = GAME_FindEnemyAdjacent(iCountry);
@@ -2027,7 +2027,7 @@ void AIColsonPlayer::finalize()
 {
   kDebug(); 
 
-  for (unsigned int i=0; i<m_game->playerList()->count(); i++)
+  for (int i=0; i<m_game->playerList()->count(); i++)
   {
     m_isEnemyPlayer[(Player*)m_game->playerList()->at(i)] = 0;
   }
@@ -2056,6 +2056,10 @@ int AIColsonPlayer::AI_Place(int iCountry, int iNumArmies)
 {
   kDebug() << iNumArmies 
             << " on country number " << iCountry;
+  if (m_placeData != 0)
+  {
+    delete m_placeData;
+  }
   m_placeData = new PlaceData();
   m_placeData->dest = m_game->game()->theWorld()->getCountries()[iCountry];
   m_placeData->nb = iNumArmies;
@@ -2081,8 +2085,8 @@ int AIColsonPlayer::AI_Move(int iSrcCountry, int iDstCountry, int iNumArmies)
   stream2 << QString("actionLButtonUp") << m_dest->centralPoint();
   aiPlayerIO()->sendInput(stream2,true);
 
-  Attack_SrcCountry = m_src->id();
-  Attack_DestCountry = m_dest->id();
+  Attack_SrcCountry = m_game->game()->theWorld()->getCountries().indexOf(const_cast<Country*>(m_src));
+  Attack_DestCountry = m_game->game()->theWorld()->getCountries().indexOf(const_cast<Country*>(m_dest));
 
   stop();
   return 0;
@@ -2117,7 +2121,7 @@ int AIColsonPlayer::RISK_GetNumArmiesOfCountry(int i)
 
 
 /** Returns the position in the countries list of the ith adjacent country of country iCountry */
-int AIColsonPlayer::RISK_GetAdjCountryOfCountry(int iCountry, unsigned int j)
+int AIColsonPlayer::RISK_GetAdjCountryOfCountry(int iCountry, int j)
 {
   Country* country = m_world->getCountries().at(iCountry);
   if (j >= country->neighbours().size())
@@ -2125,7 +2129,7 @@ int AIColsonPlayer::RISK_GetAdjCountryOfCountry(int iCountry, unsigned int j)
     return -1;
   }
   Country* neighbour = country->neighbours()[j];
-  for (unsigned int i=0; i<m_world->getCountries().size(); i++)
+  for (int i=0; i<m_world->getCountries().size(); i++)
   {
     if (m_world->getCountries().at(i) == neighbour)
     {
