@@ -13,37 +13,37 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef __KGAMELCD_H
 #define __KGAMELCD_H
 
-#include <qlcdnumber.h>
-#include <qvaluevector.h>
-#include <kdemacros.h>
+#include <QtCore/QVector>
+#include <QtGui/QLCDNumber>
+#include <libkdegames_export.h>
 
 class QLabel;
 class QTimer;
 
 //-----------------------------------------------------------------------------
 /**
- * This class is a visually enhanced @ref QLCDNumber:
+ * \class KGameLCD kgamelcd.h <KGameLCD>
+ * 
+ * This class is a visually enhanced @ref QLCDNumber :
  * <ul>
  * <li> It can show an additional string before the integer being
  * displayed.</li>
  * <li> Its foreground and background colors can easily be modified. </li>
  * <li> It can be highlighted for a short time. </li>
  * </ul>
- *
- * @since 3.2
  */
-class KDE_EXPORT KGameLCD : public QLCDNumber
+class KDEGAMES_EXPORT KGameLCD : public QLCDNumber
 {
     Q_OBJECT
 public:
-    KGameLCD(uint nbDigits, QWidget *parent = 0, const char *name = 0);
+    explicit KGameLCD(uint nbDigits, QWidget *parent = 0);
 
     ~KGameLCD();
 
@@ -84,7 +84,7 @@ public:
      */
     void setColor(const QColor &color);
 
-public slots:
+public Q_SLOTS:
     /**
      * Highlight the LCD with the QColorGourp::HighlightedText color
      * for a small time (setHighlightTime).
@@ -92,7 +92,7 @@ public slots:
     void highlight();
 
     /**
-     * Display the given integer with the (optionnal) leading string.
+     * Display the given integer with the (optional) leading string.
      *
      * Note: we cannot use display(int) since QLCDNumber::display is
      * not virtual... And you cannot use QLCDNumber::intValue() to retrieve
@@ -100,7 +100,7 @@ public slots:
      */
     void displayInt(int value);
 
-private slots:
+private Q_SLOTS:
     void timeout() { highlight(false); }
 
 private:
@@ -118,16 +118,16 @@ private:
 
 //-----------------------------------------------------------------------------
 /**
+ * \class KGameLCDClock kgamelcd.h <KGameLCD>
+ * 
  * This class is a digital clock widget. It has a maximum duration of
  * 3599 seconds (one hour) and it gets updated every second.
- *
- * @since 3.2
  */
-class KDE_EXPORT KGameLCDClock : public KGameLCD
+class KDEGAMES_EXPORT KGameLCDClock : public KGameLCD
 {
     Q_OBJECT
 public:
-    KGameLCDClock(QWidget *parent = 0, const char *name = 0);
+    KGameLCDClock(QWidget *parent = 0);
 
     ~KGameLCDClock();
 
@@ -151,7 +151,7 @@ public:
      */
     void setTime(const QString &s);
 
-public slots:
+public Q_SLOTS:
     /**
      * Stop the clock and reset it to zero.
      */
@@ -167,7 +167,7 @@ public slots:
      */
 	virtual void start();
 
-protected slots:
+protected Q_SLOTS:
     virtual void timeoutClock();
 
 private:
@@ -182,12 +182,12 @@ private:
 
 //-----------------------------------------------------------------------------
 /**
+ * \class KGameLCDList kgamelcd.h <KGameLCD>
+ * 
  * This widget holds a list of @ref QLCDNumber arranged in a vertical layout.
  * It also shows a label at the top of the list.
- *
- * @since 3.2
  */
-class KDE_EXPORT KGameLCDList : public QWidget
+class KDEGAMES_EXPORT KGameLCDList : public QWidget
 {
     Q_OBJECT
 public:
@@ -195,12 +195,16 @@ public:
      * Constructor.
      *
      * @param title is the content of the top label.
-     * @param parent passed to the QWidget constructor
-     * @param name passed to the QWidget constructor
+     * @param parent passed to the QWidget constructor.
      */
-    KGameLCDList(const QString &title,
-                 QWidget *parent = 0, const char *name = 0);
-    KGameLCDList(QWidget *parent = 0, const char *name = 0);
+    explicit KGameLCDList(const QString &title,
+                          QWidget *parent = 0);
+    /**
+     * Constructor. Create a KGameLCDList with an empty top label.
+     *
+     * @param parent passed to the QWidget constructor.
+     */
+    KGameLCDList(QWidget *parent = 0);
 
     ~KGameLCDList();
 
@@ -238,7 +242,7 @@ public:
 
 private:
     QLabel *_title;
-    QValueVector<QLCDNumber *> _lcds;
+    QVector<QLCDNumber *> _lcds;
 
     class KGameLCDListPrivate;
     KGameLCDListPrivate *d;
